<?php

namespace Drupal\orange_dam;

use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\Core\Logger\LoggerChannelFactoryInterface;
use Drupal\jfkl_orange_dam\OrangeDamContentManager;

/**
 * Manages the retrieval and validation of configuration.
 */
class OrangeDamConfigurationManager {

  /**
   * The Orange DAM configuration.
   */
  const ORANGE_DAM_CONFIG = 'orange_dam.settings';

  /**
   * Constructor.
   */
  public function __construct(
    protected ConfigFactoryInterface $configFactory,
    protected LoggerChannelFactoryInterface $loggerChannelFactory,
  ) {}

  /**
   * Get an array of allowed content type names.
   *
   * @return string[]
   *   An array of allowed content type names.
   */
  public function getContentTypeNames(): array {
    return array_keys($this->getContentTypes());
  }

  /**
   * Get the content type configuration.
   *
   * @return array
   *   An array of content type configuration.
   */
  public function getContentTypes(): array {
    $content_types = $this->configFactory
      ->get(static::ORANGE_DAM_CONFIG)
      ->get('content_types');
    if (empty($content_types)) {
      throw new \Exception(
        'Missing "orange_dam.settings content_types" configuration.'
      );
    }
    return $content_types;
  }

  /**
   * Get an array of allowed keyword types.
   *
   * @return string[]
   *   An array of allowed content types.
   */
  public function getKeywordTypes(): array {
    $tag_types = $this->configFactory
      ->get(static::ORANGE_DAM_CONFIG)
      ->get('tag_types');
    if (empty($tag_types)) {
      throw new \Exception(
        'Missing "orange_dam.settings tag_types" configuration.'
      );
    }
    return $tag_types;

  }

  /**
   * Get a list of asset formats keyed by their associated content type.
   *
   * @return string[]
   *   A list of asset formats keyed by their associated content type.
   */
  public function getAssetFormats(): array {
    $content_types = $this->getContentTypes();
    $content_type_formats = [];
    foreach ($content_types as $content_type => $content_type_configuration) {
      if (isset($content_type_configuration['asset_format'])) {
        $content_type_formats[$content_type] = $content_type_configuration['asset_format'];
      }
    }
    return $content_type_formats;
  }

  /**
   * Determine the asset format to use for a given content type.
   *
   * @param string $content_type
   *   The content type.
   *
   * @return string|false
   *   The asset format or FALSE if one was unable to be found.
   *
   * @throws \Exception
   */
  public function getAssetFormat(string $content_type) {
    $asset_formats = $this->getAssetFormats();
    if (isset($asset_formats[$content_type])) {
      return $asset_formats[$content_type];
    }
    // Log a warning if no match was found.
    $this->loggerChannelFactory->get(OrangeDamContentManager::LOGGER_CHANNEL)->warning(
      'Unable to find an asset type mapping for content type :content_type.', [
        ':content_type' => $content_type,
      ]);
    return FALSE;
  }

}
